%TEST   Simple test of POWERM_PADE.

n = 10;
A = gallery('frank',n);

fprintf('Relative residuals and errors should be of the order of\n')
fprintf('the unit roundoff, i.e., about 1e-16 or less.\n')

qvals = [2 3 12 52 365];
for q = [-qvals(end:-1:1) qvals]

    p = 1/q;
    [X,nsq,m] = powerm_pade(A,p);

    % An appropriate relative residual.
    E = zeros(n^2,n^2);
    if q > 0
       for i = 1:q
           E = E + kron((X^(q-i)).',X^(i-1));
       end
    else
       for i = 1:-q
           E = E + kron((X^(-i)).',X^(i+q-1));
       end
    end
    res = norm(A-X^q) / (norm(X)*normest(E));

    fprintf('p = %+1.0f/%3.0f,  relative_residual = %9.2e\n', ...
             sign(q), abs(q), res)

end

n = 4;
A = 0.5*eye(n) + gallery('triw',n);

% Note: this test is not necessarily valid for matrices with
% complex eigenvalues.

for p = [-9.99 -5.5 -3 -1.01 2.5 3.99 5 9.01]

    X = powerm_pade(A,p);
    Y = powerm_pade(X,1/p);
    fprintf('p = %+3.2f,   relative_error    = %9.2e\n', ...
             p, norm(A-Y,1)/norm(A,1))

end
